<?php

namespace Drupal\plupload_widget\Plugin\Field\FieldWidget;

use Drupal\Component\Utility\Bytes;

/**
 * Shared functionality between all widgets.
 */
trait PluploadWidgetTrait {

  /**
   * Get the optimum chunk size.
   *
   * This is the maximum upload size that PHP can handle. The lesser of
   * upload_max_filesize/post_max_size - we have to remove 2Kb from this to
   * account for averhead of the multipart/form-data and boundary information.
   *
   * @return float|int
   *   The optimum chunk size
   */
  public function getChunkSize() {
    $sizes = [
      Bytes::toNumber(ini_get('post_max_size')),
      Bytes::toNumber(ini_get('upload_max_filesize')),
    ];
    return min($sizes) - 2048;
  }

  /**
   * Returns the maximum configured file size for the Field stroage in Bytes.
   *
   * @return double|int
   *   The maximum file size
   */
  public function getMaxFileSize() {
    // We don't care about PHP's max post
    // or upload file size because we use
    // plupload.
    $size = $this->getFieldSetting('max_filesize');
    $size = Bytes::toNumber($size);
    return $size;
  }

}
